function love.load()
	t = {}
	inp = ""
	msg = ""
	
	blink = {0, 1}
	font = love.graphics.newFont(16)
	font_s = love.graphics.newFont(10)
	
	love.window.setTitle("Array Organizer")
	love.window.setMode(500, font:getHeight()*7)
end

function love.update(dt)
	blink[1] = blink[1] + dt
	while blink[1] >= blink[2] do
		blink[1] = blink[1] - blink[2]
	end
end

function love.draw()
	love.graphics.setFont(font)
	love.graphics.setColor(255, 255, 255, 255)
	local s = "Type the value of the latest array entry: "
	love.graphics.print(s, 5, 5)
	love.graphics.print(inp, 5+font:getWidth(s), 5)
	if blink[1] >= blink[2]/2 then
		love.graphics.print("_", 5+font:getWidth(s .. inp), 5)
	end
	
	love.graphics.setColor(205, 215, 255, 255)
	local s = ""
	if #t >= 1 then
		s = table.concat(t, " | ")
	end
	love.graphics.print("[" .. s .. "]", 10, 5+font:getHeight()*2)
	
	love.graphics.setColor(255, 215, 205, 255)
	if msg ~= "" then
		love.graphics.print(msg, 20, 5+font:getHeight()*4)
	end
	love.graphics.setFont(font_s)
	love.graphics.setColor(205, 205, 205, 255)
	love.graphics.print("'Tab' to insert value, 'Delete' to remove value, 'Enter' to generate output, 'Escape' to clear array", 3, love.window.getHeight() - font_s:getHeight())
end

function love.textinput(t)
	inp = inp .. t
	msg = ""
end

function love.keypressed(key)
	if key == "tab" or key == "insert" then
		local s = string.gsub(inp, ",", ".")
		if tonumber( s ) then
			table.insert(t, tonumber( s ))
			inp = ""
			msg = ""
		else
			msg = "Invalid number inserted"
		end
	elseif key == "delete" then
		table.remove(t)
	elseif key == "backspace" then
		if string.len(inp) > 1 then
			inp = string.sub(inp, 1, -2)
		else
			inp = ""
		end
		msg = ""
	elseif key == "enter" or key == "return" or key == "kpenter" then
		love.keypressed("tab")
		if msg == "" or inp == "" then
			msg = "Output: {" .. table.concat(order(t), ", ") .. "}"
		end
	elseif key == "escape" then
		t = {}
		inp = ""
		msg = ""
	end
end

function order(t) --input table
	local ret = {} --returning table
	local first = true
	for i, v in pairs(t) do --main loop
		if first then --first item
			ret = {v}
			first = false
		elseif v >= ret[#ret] then --skip ahead
			table.insert(ret, v)
		elseif v <= ret[1] then --put it first
			table.insert(ret, 1, v)
		else
			local pos = 1
			for j = 2, #ret-1 do --secondary loop
				if v >= ret[j] then
					pos = j
				else
					break
				end
			end
			table.insert(ret, pos+1, v)
		end
	end
	return ret --output table
end

function love.window.getWidth()
	local ww, hh = love.window.getMode()
	return ww
end

function love.window.getHeight()
	local ww, hh = love.window.getMode()
	return hh
end